#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#       combac.py
#
#       Copyright 2014 BFR <info@freie-radios.de>
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; Version 3 of the License
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, the license can be downloaded here:
#
#       http://www.gnu.org/licenses/gpl.html
import codecs
import datetime
import sys
import threading

import simplejson

from libraries.database.broadcasts import TimeSlot, TimeSlotEntry
from libraries.reporting.messenger import AuraMessenger
from modules.communication.zmq.zmqadapter import ClientZMQAdapter


class AuraCalendarService(threading.Thread):
    messenger = AuraMessenger()
    calendarurl = ""
    audiobase = ""
    playlistdir = ""
    until = ''
    secondspertrack = 0
    xmlplaylist = range(0)

    config = None
    zmqclient = None


    """
    Fetching playlist data, write it into the database and notify service
    """
    def __init__(self, config, datefrom="", dateto=""):
        threading.Thread.__init__(self)
        self.config = config

        self.messenger.setChannel('aura')
        self.messenger.setSection('getcalendar')
        self.messenger.setMailAddresses(self.config.get('frommail'), self.config.get('adminmail'))

        self.zmqclient = ClientZMQAdapter(self.config.get('zmqhostip'), self.config.get('zmqport'))

        self.dateto = dateto
        self.datefrom = str(datefrom)

    # ------------------------------------------------------------------------------------------ #
    def setDateFrom(self, date):
        self.datefrom = str(date).replace(" ", "T")

    # ------------------------------------------------------------------------------------------ #
    def setDateTo(self, date):
        self.dateto = str(date).replace(" ", "T")

    # ------------------------------------------------------------------------------------------ #
    def setUntilTime(self, timestring):
        self.until = timestring

    # ------------------------------------------------------------------------------------------ #
    def setSecondsPerTrack(self, seconds):
        self.secondspertrack = int(seconds)

    # ------------------------------------------------------------------------------------------ #
    def setCalendarUrl(self, url):
        self.calendarurl = url

    # ------------------------------------------------------------------------------------------ #
    def setAudioPath(self, path):
        self.audiobase = path

    # ------------------------------------------------------------------------------------------ #
    def setAudioPath(self, path):
        self.audiobase = path

    # ------------------------------------------------------------------------------------------ #
    def setPlaylistStore(self, path):
        self.playlistdir = path

    # ------------------------------------------------------------------------------------------ #
    def getDuration(self, start, end):
        return self._calcDuration(start, end)

    # ------------------------------------------------------------------------------------------ #
    def getUri(self):
        if not self.playlistdir:
            return False
        if not self.datefrom:
            return False
        if not self._calcDateTo():
            return
        hostname = self.get('servername');
        port = self.get('serviceport');
        date_from = self.datefrom[0:16] + ':00';
        date_to = self.dateto[0:16] + ':00';
        uri = 'http://' + hostname  + ':' + port + '/playlist/' + date_from + '/' + date_to

        return uri

    # ------------------------------------------------------------------------------------------ #
    def run(self):
        """
        Fetch calendar data, store it in the database and send a message to the aura service
        """
        filestotal = 0
        #if not self._calcDateTo():
        #    return

        self._setUrl()
        self._fetchData()

        # secondspertrack  may be a string from config
        self.secondspertrack = int(self.secondspertrack)

        #print(self.data['timeslots'])
        entrynum = 0
        lasttimeslot_id = 0
        for timeslot in self.data:
            #fix nonexisting origdatetime
            if 'end' not in timeslot:
                continue
            if 'start' not in timeslot:
                continue

            timeslot_db = TimeSlot.query.filter(TimeSlot.timeslot_id == timeslot['timeslot_id']).first()
            if not timeslot_db:
                print("no timeslot with given timeslot id in database => create new")
                timeslot_db = TimeSlot()

            timeslot_entry = TimeSlotEntry.query.filter(TimeSlotEntry.entry_start == timeslot["start"], TimeSlotEntry.entry_end == timeslot["end"]).first()
            if not timeslot_entry:
                print("no timeslotentry from "+timeslot["start"]+" to "+timeslot["end"]+" found")
                timeslot_entry = TimeSlotEntry()

            # calc duration
            duration = self._calcDuration(timeslot['start'], timeslot['end'])
            timeslot['duration'] = datetime.timedelta(seconds=duration).__str__()

#            print("is " + str(lasttimeslot_id) + " == " + str(timeslot["timeslot_id"]))
#            if lasttimeslot_id == timeslot["timeslot_id"]:
#                print("yes")
#                entrynum = entrynum + 1
#            else:
#                print("no")
#                entrynum = 0
#                lasttimeslot_id = timeslot["timeslot_id"]

            timeslot_db.show_id = timeslot["show_id"]
            timeslot_db.timeslot_id           = timeslot["timeslot_id"]
            timeslot_db.timeslot_start        = timeslot["timeslot_start"]
            timeslot_db.timeslot_end          = timeslot["timeslot_end"]

            timeslot_db.show_name             = timeslot["show_name"]
            timeslot_db.show_hosts            = timeslot["show_hosts"]
            timeslot_db.is_repetition         = timeslot["is_repetition"]
            timeslot_db.fallback_playlist     = timeslot["fallback_playlist"]
            timeslot_db.show_fallback_pool    = timeslot["show_fallback_pool"]
            timeslot_db.station_fallback_pool = timeslot["station_fallback_pool"]

            timeslot_entry.timeslot_id        = timeslot["timeslot_id"]
            timeslot_entry.entry_start        = timeslot["start"]
            timeslot_entry.entry_end          = timeslot["end"]
            timeslot_entry.source             = timeslot["source"]

            timeslot_db.store(True)
            timeslot_entry.store(True)

            event = {'job': 'dump', 'location': timeslot['timeslot_id'], 'length': duration}
            self.messenger.queueAddEvent('dumpstart', timeslot["start"], event, 'recorder')

            event = {'job': 'dump', 'location': timeslot['timeslot_id'], 'length': duration}
            self.messenger.queueAddEvent('dumpend', timeslot["end"], event, 'recorder')

        self.zmqclient.send("newprogramme")

    # ------------------------------------------------------------------------------------------ #
    def _calcDateTo(self):
        if self.dateto:
            return True
        if not self.until:
            return False
        if not self.datefrom:
            return False
        date_start = datetime.datetime.strptime(self.datefrom.replace('T',' '), "%Y-%m-%d %H:%M")
        time_start = date_start.strftime('%H:%M')
        day_offset = 1 if (time_start > self.until) else 0
        end_date = date_start + datetime.timedelta(day_offset)
        self.dateto = end_date.strftime('%F') + 'T' + self.until
        return True

    # ------------------------------------------------------------------------------------------ #
    def _calcDuration(self, start, end):
        """
        Berechnet Zeit in Sekunden aus Differenz zwischen Start und Enddatum
        @type start: datetime
        @param start: Startzeit
        @type end: datetime
        @param end: Endzeit
        @rtype:       int
        @return:      Zeit in Sekunden
        """
        sec1 = int(datetime.datetime.strptime(start[0:16].replace(" ","T"),"%Y-%m-%dT%H:%M").strftime("%s"));
        sec2 = int(datetime.datetime.strptime(end[0:16].replace(" ","T"),"%Y-%m-%dT%H:%M").strftime("%s"));
        return (sec2 - sec1);


    # ------------------------------------------------------------------------------------------ #
    def _fetchData(self):

        # Now open Calendar Url
        try:
            url = self.getUrl()
            data = self.getData()

            #request = urllib.request.Request(url, data)
            #with urllib.request.urlopen(request) as response:
            #    html_response = response.read()

            html_response = '[{"source": "file://path/to/interview_mit_luger.flac", "start": "2017-10-09 18:03:00", "end": "2017-10-09 18:05:40", "timeslot_id": 1, "timeslot_start": "2017-10-09 18:00:00", "timeslot_end": "2017-10-09 19:00:00", "show_id": 1, "show_name": "FROzine", "show_hosts": "Sandra Hochholzer, Martina Schweiger", "is_repetition": false, "fallback_playlist": "file:///var/audio/music.flac", "show_fallback_pool": "file:///var/audio/fallback/", "station_fallback_pool": "file:///var/audio/station_fallback_pool/"},{"source": "file://path/to/interview_mit_luger.flac", "start": "2017-10-09 18:05:40", "end": "2017-10-09 19:00:00", "timeslot_id": 1, "timeslot_start": "2017-10-09 18:00:00", "timeslot_end": "2017-10-09 19:00:00", "show_id": 1, "show_name": "FROzine", "show_hosts": "Sandra Hochholzer, Martina Schweiger", "is_repetition": false, "fallback_playlist": "file:///var/audio/music.ogg", "show_fallback_pool": "file:///var/audio/fallback/", "station_fallback_pool": "file:///var/audio/station_fallback_pool/"}, {"source": "file://path/to/interview_mit_luger.flac", "start": "2017-10-09 19:00:00", "end": "2017-10-09 20:00:00", "timeslot_id": 2, "timeslot_start": "2017-10-09 19:00:00", "timeslot_end": "2017-10-09 20:00:00", "show_id": 2, "show_name": "FROzine", "show_hosts": "Sandra Hochholzer, Martina Schweiger", "is_repetition": true, "fallback_playlist": "file://path/to/playlist.m3u", "show_fallback_pool": "file:///var/audio/fallback/", "station_fallback_pool": "file:///var/audio/station_fallback_pool/"}]'

        except IOError as e:
            self.messenger.send("Could not connect to service " + self.dataURL, '1101', 'error', 'fetchCalenderData',
                                self._getErrorData(), 'getcalendar')
            #TODO: so gehts nicht
            sys.exit()
        else:
            # Read in data
            #print(html_response[0:100])
            #jsondata = html_response # .read()

            # print("Hardcoded Response for this request: http://bermudafunk-kalender.critmass.de/index.php?option=com_jimtawl&view=calendar&format=json&from=2017-09-26T08:00&to=2017-09-27T07:00")
            print("Hardcoded Response")
            jsondata = '[{"source": "file:///var/audio/music.flac", "start": "2017-10-09 18:03:00", "end": "2017-10-09 18:05:40", "timeslot_id": 1, "timeslot_start": "2017-10-09 18:00:00", "timeslot_end": "2017-10-09 19:00:00", "show_id": 1, "show_name": "FROzine", "show_hosts": "Sandra Hochholzer, Martina Schweiger", "is_repetition": false, "fallback_playlist": "file:///var/audio/music.flac", "show_fallback_pool": "file:///var/audio/fallback/", "station_fallback_pool": "file:///var/audio/station_fallback_pool/"},{"source": "file://path/to/interview_mit_luger.flac", "start": "2017-10-09 18:05:40", "end": "2017-10-09 19:00:00", "timeslot_id": 1, "timeslot_start": "2017-10-09 18:00:00", "timeslot_end": "2017-10-09 19:00:00", "show_id": 1, "show_name": "FROzine", "show_hosts": "Sandra Hochholzer, Martina Schweiger", "is_repetition": false, "fallback_playlist": "file:///var/audio/music.ogg", "show_fallback_pool": "file:///var/audio/fallback/", "station_fallback_pool": "file:///var/audio/station_fallback_pool/"}, {"source": "file://path/to/interview_mit_luger.flac", "start": "2017-10-09 19:00:00", "end": "2017-10-09 20:00:00", "timeslot_id": 2, "timeslot_start": "2017-10-09 19:00:00", "timeslot_end": "2017-10-09 20:00:00", "show_id": 2, "show_name": "FROzine", "show_hosts": "Sandra Hochholzer, Martina Schweiger", "is_repetition": true, "fallback_playlist": "file://path/to/playlist.m3u", "show_fallback_pool": "file:///var/audio/fallback/", "station_fallback_pool": "file:///var/audio/station_fallback_pool/"}]'
            #jsondata = '{"num":17,"shows":[{"identifier":"748-2017-09-26-08-00-00","reccurrence_id":"748","start":"2017-09-26 08:00:00","end":"2017-09-26 09:00:00","datetime":"2017-09-26 08:00:00","duration":"01:00:00","rerun":false,"title":"Darktales Radio-Show","subject":"","description":"","text":"","programme_id":"25","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"749-2017-09-26-09-00-00","reccurrence_id":"749","start":"2017-09-26 09:00:00","end":"2017-09-26 11:00:00","datetime":"2017-09-26 09:00:00","duration":"02:00:00","rerun":false,"title":"Bizarre","subject":"","description":"","text":"","programme_id":"14","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"750-2017-09-26-11-00-00","reccurrence_id":"750","start":"2017-09-26 11:00:00","end":"2017-09-26 12:00:00","datetime":"2017-09-26 11:00:00","duration":"01:00:00","rerun":false,"title":"Netzwerk XX","subject":"","description":"","text":"","programme_id":"74","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"1034-2017-09-26-12-00-00","reccurrence_id":"1034","start":"2017-09-26 12:00:00","end":"2017-09-26 14:00:00","datetime":"2017-09-26 12:00:00","duration":"02:00:00","rerun":false,"title":"POPPATCHWORK","subject":"","description":"","text":"","programme_id":"114","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"","email":"email@bermudafunk.org"}},{"identifier":"1035-2017-09-26-14-00-00","reccurrence_id":"1035","start":"2017-09-26 14:00:00","end":"2017-09-26 15:00:00","datetime":"2017-09-26 14:00:00","duration":"01:00:00","rerun":false,"title":"Lieder und Worte","subject":"","description":"","text":"","programme_id":"115","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"","email":"email@bermudafunk.org"}},{"identifier":"601-2017-09-26-15-00-00","reccurrence_id":"601","start":"2017-09-26 15:00:00","end":"2017-09-26 16:00:00","datetime":"2017-09-26 15:00:00","duration":"01:00:00","rerun":false,"title":"Ohrenschmaus","subject":"","description":"","text":"","programme_id":"77","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"377-2017-09-26-16-00-00","reccurrence_id":"377","start":"2017-09-26 16:00:00","end":"2017-09-26 18:00:00","datetime":"2017-09-26 16:00:00","duration":"02:00:00","rerun":false,"title":"Sonar","subject":"","description":"","text":"","programme_id":"95","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"754-2017-09-26-18-00-00","reccurrence_id":"754","start":"2017-09-26 18:00:00","end":"2017-09-26 20:00:00","datetime":"2017-09-26 18:00:00","duration":"02:00:00","rerun":false,"title":"No Water","subject":"","description":"","text":"","programme_id":"76","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"611-2017-09-26-20-00-00","reccurrence_id":"611","start":"2017-09-26 20:00:00","end":"2017-09-26 21:00:00","datetime":"2017-09-26 20:00:00","duration":"01:00:00","rerun":false,"title":"Leonardo","subject":"","description":"","text":"","programme_id":"63","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"605-2017-09-26-21-00-00","reccurrence_id":"605","start":"2017-09-26 21:00:00","end":"2017-09-26 22:00:00","datetime":"2017-09-26 21:00:00","duration":"01:00:00","rerun":false,"title":"bermuda.music","subject":"","description":"","text":"","programme_id":"11","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"612-2017-09-26-22-00-00","reccurrence_id":"612","start":"2017-09-26 22:00:00","end":"2017-09-27 00:00:00","datetime":"2017-09-26 22:00:00","duration":"02:00:00","rerun":false,"title":"Clubbers Paradise","subject":"","description":"","text":"","programme_id":"20","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"629-2017-09-27-00-00-00","reccurrence_id":"629","start":"2017-09-27 00:00:00","end":"2017-09-27 01:00:00","datetime":"2017-09-27 00:00:00","duration":"01:00:00","rerun":false,"title":"Worte ueber die Welt","subject":"","description":"","text":"","programme_id":"109","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"755-2017-09-27-01-00-00","reccurrence_id":"755","start":"2017-09-27 01:00:00","end":"2017-09-27 03:00:00","datetime":"2017-09-27 01:00:00","duration":"02:00:00","rerun":false,"title":"Grenzenlos","subject":"","description":"","text":"","programme_id":"43","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"756-2017-09-27-03-00-00","reccurrence_id":"756","start":"2017-09-27 03:00:00","end":"2017-09-27 04:00:00","datetime":"2017-09-27 03:00:00","duration":"01:00:00","rerun":false,"title":"bermuda.music special","subject":"","description":"","text":"","programme_id":"12","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"757-2017-09-27-04-00-00","reccurrence_id":"757","start":"2017-09-27 04:00:00","end":"2017-09-27 05:00:00","datetime":"2017-09-27 04:00:00","duration":"01:00:00","rerun":false,"title":"radio.aufschnitt","subject":"","description":"","text":"","programme_id":"86","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"758-2017-09-27-05-00-00","reccurrence_id":"758","start":"2017-09-27 05:00:00","end":"2017-09-27 06:00:00","datetime":"2017-09-27 05:00:00","duration":"01:00:00","rerun":false,"title":"PRESSING","subject":"","description":"","text":"","programme_id":"83","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}},{"identifier":"684-2017-09-27-06-00-00","reccurrence_id":"684","start":"2017-09-27 06:00:00","end":"2017-09-27 08:00:00","datetime":"2017-09-27 06:00:00","duration":"02:00:00","rerun":false,"title":"Sonar","subject":"","description":"","text":"","programme_id":"95","station_name":"Bermudafunk","station_id":"bfunk-003","data":{"www":"bermudafunk.org","email":"email@bermudafunk.org"}}]}'
            #jsondata = '{"num":5,"shows":[{"id":"0","name":"frozine","slug":"","image":"","logo":"","description":"25","type":"Magazin","is_repetition":false,"start":"2017-09-26 08:00:00","end":"2017-09-26 09:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"1","name":"bücherwahl","slug":"","image":"","logo":"","description":"25","type":"Magazin","is_repetition":false,"start":"2017-09-26 09:00:00","end":"2017-09-26 10:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"2","name":"sonar","slug":"","image":"","logo":"","description":"25","type":"Magazin","is_repetition":false,"start":"2017-09-26 10:00:00","end":"2017-09-26 11:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"3","name":"Radio Bulgaria","slug":"","image":"","logo":"","description":"25","type":"Magazin","is_repetition":false,"start":"2017-09-26 11:00:00","end":"2017-09-26 12:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"4","name":"#Stimmlagen","slug":"","image":"","logo":"","description":"25","type":"Magazin","is_repetition":false,"start":"2017-09-26 12:00:00","end":"2017-09-26 13:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"}]}'
            #jsondata = '{"num":5,"timeslots":[{"id":"0","name":"frozine","slug":"","image":"","logo":"","description":"25","location":"file:///var/audio/test.flac","type":"file to lineout","is_repetition":false,"start":"2017-09-26 13:00:00","end":"2017-09-26 14:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"1","name":"bücherwahl","slug":"","image":"","logo":"","description":"25","location":"http://develop.servus.at:8000/listen.pls","type":"stream to lineout","is_repetition":false,"start":"2017-09-26 09:00:00","end":"2017-09-26 10:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"2","name":"sonar","slug":"","image":"","logo":"","description":"25","location":"linein:///var/audio/test.flac","type":"linein to lineout","is_repetition":false,"start":"2017-09-26 10:00:00","end":"2017-09-26 11:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"3","name":"Radio Bulgaria","slug":"","image":"","logo":"","description":"25","location":"pool:///var/audio/","type":"file (pool) to lineout","is_repetition":false,"start":"2017-09-26 11:00:00","end":"2017-09-26 12:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"4","name":"#Stimmlagen","slug":"","image":"","logo":"","description":"25","location":"file:///var/audio/test.flac","type":"file to lineout","is_repetition":false,"start":"2017-09-26 12:00:00","end":"2017-09-26 13:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"}]}'
            #jsondata = '{"num":5,"timeslots":[{"id":"0","name":"frozine","slug":"","image":"","logo":"","description":"25","location":"file:///var/audio/test.flac","type":"file to lineout","is_repetition":false,"origdate":"","start":"2017-09-26 13:00:00","end":"2017-09-26 14:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"1","name":"bücherwahl","slug":"","image":"","logo":"","description":"25","location":"http://develop.servus.at:8000/listen.pls","type":"stream to lineout","is_repetition":false,"origdate":"","start":"2017-09-26 09:00:00","end":"2017-09-26 10:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"2","name":"sonar","slug":"","image":"","logo":"","description":"25","location":"linein:///var/audio/test.flac","type":"linein to lineout","is_repetition":false,"origdate":"","start":"2017-09-26 10:00:00","end":"2017-09-26 11:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"3","name":"Radio Bulgaria","slug":"","image":"","logo":"","description":"25","location":"pool:///var/audio/","type":"file (pool) to lineout","is_repetition":false,"origdate":"","start":"2017-09-26 11:00:00","end":"2017-09-26 12:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"4","name":"#Stimmlagen","slug":"","image":"","logo":"","description":"25","location":"file:///var/audio/test.flac","type":"file to lineout","is_repetition":false,"origdate":"","start":"2017-09-26 12:00:00","end":"2017-09-26 13:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"}]}'
            #jsondata = '{"timeslots":[{"id":"0","name":"frozine","playlist_id":"file:///var/audio/test.flac","shortdesc":"test description","repetition_id":"","start":"2017-09-26 10:00:00","end":"2017-09-26 11:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"0","name":"frozine","playlist_id":"http://fro.at:8000/listen.pls","shortdesc":"test description","repetition_id":"","start":"2017-09-26 11:00:00","end":"2017-09-26 12:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"0","name":"frozine","playlist_id":"file:///var/audio/test.flac","shortdesc":"test description","repetition_id":"","start":"2017-09-26 12:00:00","end":"2017-09-26 13:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"0","name":"frozine","playlist_id":"file:///var/audio/test.flac","shortdesc":"test description","repetition_id":"","start":"2017-09-26 13:00:00","end":"2017-09-26 14:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"0","name":"frozine","playlist_id":"file:///var/audio/test.flac","shortdesc":"test description","repetition_id":"","start":"2017-09-26 14:00:00","end":"2017-09-26 15:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"}]}'
            #jsondata = '{"timeslots":[{"id":"0","name":"frozine","playlist_id":"file:///var/audio/test.flac","shortdesc":"test description","start":"2017-09-26 10:00:00","end":"2017-09-26 11:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"1","name":"bücherwahl","playlist_id":"http://fro.at:8000/listen.pls","shortdesc":"test description","start":"2017-09-26 11:00:00","end":"2017-09-26 12:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"2","name":"Radio Bulgari","playlist_id":"pool:///var/audio/","shortdesc":"test description","start":"2017-09-26 12:00:00","end":"2017-09-26 13:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"3","name":"FROmat","playlist_id":"file:///var/audio/test.flac","shortdesc":"test description","start":"2017-09-26 13:00:00","end":"2017-09-26 14:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"},{"id":"4","name":"frozine","playlist_id":"file:///var/audio/test.flac","shortdesc":"test description","repetition_id":1,"start":"2017-09-26 14:00:00","end":"2017-09-26 15:00:00","fallback_pool":"/var/audio","fallback_playlist":"/var/audio/fallback.pls"}]}'
            try:
                self.data = simplejson.loads(jsondata)
            except Exception as e:
                self.messenger.send("Could not decode calender data from service " + self.dataURL + "! Exception: "+e, '1102', 'error',
                                    'fetchCalenderData', self._getErrorData(), 'getcalendar')
                sys.exit()
            else:
                # check data
                try:
                    print("json data not really checked. i believe what i get")
                    #print(self.data)
                    #print(len(self.data))
                except KeyError as e:
                    self.messenger.send("Could not decode calender data from service " + self.dataURL + "! Exception: "+e, '1102', 'error',
                                        'fetchCalenderData', self._getErrorData(), 'getcalendar')
                    sys.exit()
                except Exception as e:
                    self.messenger.send("Could not decode calender data from service " + self.dataURL + "! Exception: "+e, '1102', 'error',
                                        'fetchCalenderData', self._getErrorData(), 'getcalendar')
                    sys.exit()

                else:
                    return self.data

    # ------------------------------------------------------------------------------------------ #
    def _dumpPlaylist(self, xml):
        """
        Dump the playlist
        @type xml: string
        @param xml: XML-String
        """
        # dump file
        try:
            f = codecs.open(self.playlistpath + '.xspf', 'w', encoding='utf-8')
            f.write(xml)
            f.close()
        except:
            self.messenger.send("Couldn't dump playlist " + self.playlistpath + '.xspf', '1201', 'error', 'get_playlist', self._getErrorData(), 'getcalendar')
        else:
            self.messenger.send("Dumped playlist" + self.playlistpath + ".xspf", '1200', 'success', 'get_playlist', self._getErrorData(), 'getcalendar')

    # ------------------------------------------------------------------------------------------ #
    def _getErrorData(self):
        """
        Basisdaten als dict liefern
        """
        return ({'from': str(self.datefrom), 'dateto': str(self.dateto), 'path': "self.playlistpath", 'url': self.calendarurl})

    # ------------------------------------------------------------------------------------------ #
    def _setUrl(self):
        """
        Die URL auf den Zappa-Kalender ermitteln
        """
        #print(self.calendarurl)
        self.dataURL = self.calendarurl.replace('#datefrom#', self.datefrom.replace(' ', 'T')).replace('#dateto#', self.dateto.replace(' ', 'T'))
        #print("URL set: "+self.dataURL)

    def getUrl(self):
        url = self.dataURL[0:self.dataURL.find('&')]
        print(url)
        return url

    def getData(self):
        params = self.dataURL[self.dataURL.find('&'):]
        #print("params: "+params)

    def getCalendarData(self):
        return self.data